from django.urls import path,include
from . import views
from . import apiviews
from rest_framework_simplejwt import views as jwt_views

urlpatterns = [
    # JWT Token endpoints for external systems to get access
    path('api/token/', jwt_views.TokenObtainPairView.as_view(), name='token_obtain_pair'),
    path('api/token/refresh/', jwt_views.TokenRefreshView.as_view(), name='token_refresh'),
    path("api/payments/", apiviews.receive_payment, name="receive_payment"),
    path('api/users/', apiviews.UserDetailView.as_view(), name='user-detail'),
    
    # Views
    path("", views.index, name="index"),
    path('register/', views.register, name='register'),
    path('login/', views.user_login, name='login'),
    path('logout/', views.user_logout, name='logout'),
    path('dashboard/', views.dashboard, name='dashboard'),
    
    # Fix: Remove email parameter from verify_email
    path('verify-email/', views.verify_email, name='verify_email'),  
    path('resend-otp/', views.resend_otp, name='resend_otp'),
    path("password-reset/", views.request_password_reset, name="password_reset"),
    path("password-reset/<str:token>/", views.reset_password, name="reset_password"),
    # path("api/deposit/", views.deposit, name="deposit"),
    path('withdraw/', views.withdraw, name='withdraw'),
    path('transfer/', views.transfer, name='transfer'),

    path("add-payment-method/", views.add_payment_method, name="add_payment_method"),

    path('about/', views.about_us, name='about_us'),
    path('privacy/', views.privacy_policy, name='privacy_policy'),
    path("delete-credit-card/", views.delete_credit_card, name="delete_credit_card"),
    path("delete-bank-account/", views.delete_bank_account, name="delete_bank_account"),

    path('pay-activation/', views.pay_activation_fee, name='pay_activation_fee'),
    path("payment-success/", views.payment_success, name="payment_success"),

    path("payment-cancel/", views.payment_cancel, name="payment_cancel"),
    path("settings/", views.account_settings, name="account_settings"),
    
    
    path("faq/", views.faq_view, name="faq"),
    path("terms/", views.terms_view, name="terms"),
    path("articles/", views.articles_view, name="articles"),
    
    
    path("notifications/mark-as-read/<int:notification_id>/", views.mark_as_read, name="mark_as_read"),
    path("notifications/delete/<int:notification_id>/", views.delete_notification, name="delete_notification"),
 ]
